@@ -101,9 +101,12 @@ function getSuggestions(label) {
 
     for (var i = 0; i < menuitems.length; i++) {
         var menuitem = menuitems[i];
-        suggestions.push(menuitem + theCase + indtype + indstr);
+        if (isCaseLabel(menuitem)) {
+            menuitem += theCase;
+        }
+        suggestions.push(menuitem + indtype + indstr);
     }
-    return suggestions.unique();
+    return _.uniq(suggestions);
 }
 
 /**
@@ -270,6 +273,7 @@ function doConLeaf(conleaf, node) {
 // " "hideContextMenu" "clearSelection" "toggleExtension" "selectNode\
 // " "parseIndex" "parseLabel" "defaultConMenuGroup" "getIndex" "parseIndexType\
 // " "displayCaseMenu" "caseTags" "casePhrases" "hasCase" "touchTree\
-// " "startnode" "_" "setCase" "caseBarriers" "isCasePhrase" "isCaseNode")
+// " "startnode" "_" "setCase" "caseBarriers" "isCasePhrase" "isCaseNode\
+// " "isCaseLabel" "labelHasCase" "labelGetCase" "labelRemoveCase")
 // indent-tabs-mode: nil
 // End:
