@@ -104,24 +104,17 @@ var lemmataStyleNode, lemmataHidden = true;
 
 var currentIndex = 1; // TODO: move to where it goes
 
-String.prototype.startsWith = function(str) {
-    return (this.substr(0,str.length) === str);
-};
+if (typeof String.prototype.startsWith !== 'function') {
+    String.prototype.startsWith = function(str) {
+        return (this.substr(0, str.length) === str);
+    };
+}
 
-String.prototype.endsWith = function(str) {
-    return (this.substr(this.length-str.length) === str);
-};
-
-/*
- * unique function by: Shamasis Bhattacharya
- * http://www.shamasis.net/2009/09/fast-algorithm-to-find-unique-items-in-javascript-array/
- */
-Array.prototype.unique = function() {
-    var o = {}, i, l = this.length, r = [];
-    for(i=0; i<l;i+=1) o[this[i]] = this[i];
-    for(i in o) r.push(o[i]);
-    return r;
-};
+if (typeof String.prototype.endsWith !== 'function') {
+    String.prototype.endsWith = function(str) {
+        return (this.substr(this.length - str.length) === str);
+    };
+}
 
 function navigationWarning() {
     if ($("#editpane").html() != lastsavedstate) {
